summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopetecontact.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopetecontact.cpp')
-rw-r--r--kopete/libkopete/kopetecontact.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/kopete/libkopete/kopetecontact.cpp b/kopete/libkopete/kopetecontact.cpp
index 029565d0..66ecf11f 100644
--- a/kopete/libkopete/kopetecontact.cpp
+++ b/kopete/libkopete/kopetecontact.cpp
@@ -79,15 +79,15 @@ public:
};
Contact::Contact( Account *account, const TQString &contactId,
- MetaContact *tqparent, const TQString &icon )
- : TQObject( tqparent )
+ MetaContact *parent, const TQString &icon )
+ : TQObject( parent )
{
d = new Private;
//kdDebug( 14010 ) << k_funcinfo << "Creating contact with id " << contactId << endl;
d->contactId = contactId;
- d->metaContact = tqparent;
+ d->metaContact = parent;
d->fileCapable = false;
d->account = account;
d->idleTime = 0;
@@ -101,15 +101,15 @@ Contact::Contact( Account *account, const TQString &contactId,
connect( account, TQT_SIGNAL( isConnectedChanged() ), TQT_SLOT( slotAccountIsConnectedChanged() ) );
}
// Need to check this because myself() may have no tqparent
// Maybe too the metaContact doesn't have a valid protocol()
// (ex: for unit tests or chat window style preview)
- if( tqparent && protocol() )
+ if( parent && protocol() )
{
- connect( tqparent, TQT_SIGNAL( aboutToSave( Kopete::MetaContact * ) ),
+ connect( parent, TQT_SIGNAL( aboutToSave( Kopete::MetaContact * ) ),
protocol(), TQT_SLOT( slotMetaContactAboutToSave( Kopete::MetaContact * ) ) );
- tqparent->addContact( this );
+ parent->addContact( this );
}
@@ -101,15 +101,15 @@ Contact::Contact( Account *account, const TQString &contactId,
connect( account, TQT_SIGNAL( isConnectedChanged() ), TQT_SLOT( slotAccountIsConnectedChanged() ) );
}
- // Need to check this because myself() may have no tqparent
+ // Need to check this because myself() may have no parent
// Maybe too the metaContact doesn't have a valid protocol()
// (ex: for unit tests or chat window style preview)